@@ -4,9 +4,8 @@ use strict;
 use warnings;
 
 use Scalar::Util qw( blessed );
-use UNIVERSAL::require;
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
 # ----------------------------------------------
 
@@ -342,6 +341,9 @@ Stevan Little E<lt>stevan.little@iinteractive.comE<gt>
 
 Thanks to Infinity Interactive for generously donating our time.
 
+Co-maintenance since V 1.01 is by Ron Savage <rsavage@cpan.org>.
+Uses of 'I' in previous versions is not me, but will be hereafter.
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 2004, 2005 by Infinity Interactive, Inc.
