@@ -7,7 +7,7 @@ use base qw( Tree::Persist::Base );
 
 use Scalar::Util qw( blessed );
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
 # ----------------------------------------------
 
@@ -71,14 +71,26 @@ parameters are used by C<connect()> or C<create_datastore()>:
 
 =over 4
 
-=item * type (required)
+=item * class (optional)
 
-For any File::* plugin to be used, the type must be 'File' (case-sensitive).
+This is the name of a user-supplied class for deflation/inflation.
+
+The C<class> parameter takes precedence over the C<type> parameter.
+
+If C<class> is not provided, C<type> is used, and defaults to 'File'. Then C<class> is determined using:
+
+	$class = $type eq 'File' ? 'Tree::Persist::File::XML' : 'Tree::Persist::DB::SelfReferential';
+
+See t/save_and_load.t for sample code.
 
 =item * filename (required)
 
 This is the filename that will be used as the datastore.
 
+=item * type (optional)
+
+For any File::* plugin to be used, the type must be 'File' (case-sensitive) unless a C<class> is provided.
+
 =back
 
 =head1 METHODS
@@ -111,6 +123,9 @@ Stevan Little E<lt>stevan.little@iinteractive.comE<gt>
 
 Thanks to Infinity Interactive for generously donating our time.
 
+Co-maintenance since V 1.01 is by Ron Savage <rsavage@cpan.org>.
+Uses of 'I' in previous versions is not me, but will be hereafter.
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 2004, 2005 by Infinity Interactive, Inc.
